<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  com_hobosm
 *
 * @copyright   Copyright (C) 2005 - 2018 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

use Joomla\Registry\Registry;

/**
 * HobOsm Model
 *
 * @since  0.0.1
 */
class HobosmModelLicense extends JModelAdmin
{
    /**
     * Method to override getItem to allow us to convert the JSON-encoded image information
     * in the database record into an array for subsequent prefilling of the edit form
     */
    public function getItem($pk = null)
    {
        $item = parent::getItem($pk);
        if ($item AND property_exists($item, 'image'))
        {
            $registry = new Registry($item->image);
            $item->imageinfo = $registry->toArray();
        }
        return $item;
    }

    public function getActiveLicense(){
	    $db    = JFactory::getDbo();
	    $query = $db->getQuery(true);

	    // Create the base select statement.
	    $query->select('*')
		    ->from($db->quoteName('#__hobosm_license_active'));
	    $db->setQuery((string)$query);
	    $result = $db->loadObject();
	    return $result;
    }
    /**
     * Method to get a table object, load it if necessary.
     *
     * @param   string  $type    The table name. Optional.
     * @param   string  $prefix  The class prefix. Optional.
     * @param   array   $config  Configuration array for model. Optional.
     *
     * @return  JTable  A JTable object
     *
     * @since   1.6
     */
    public function getTable($type = 'License', $prefix = 'HobOsmTable', $config = array())
    {
        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get the record form.
     *
     * @param   array    $data      Data for the form.
     * @param   boolean  $loadData  True if the form is to load its own data (default case), false if not.
     *
     * @return  mixed    A JForm object on success, false on failure
     *
     * @since   1.6
     */
    public function getForm($data = array(), $loadData = true)
    {
        // Get the form.
        $form = $this->loadForm(
            'com_hobosm.license',
            'license',
            array(
                'control' => 'jform',
                'load_data' => $loadData
            )
        );

        if (empty($form))
        {
            return false;
        }

        return $form;
    }
    /**
     * Method to get the script that have to be included on the form
     *
     * @return string	Script files
     */
    public function getScript()
    {
        return 'administrator/components/com_hobosm/models/forms/hobosm.js';
    }
    /**
     * Method to get the data that should be injected in the form.
     *
     * @return  mixed  The data for the form.
     *
     * @since   1.6
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $data = JFactory::getApplication()->getUserState(
            'com_hobosm.license.data',
            array()
        );

        if (empty($data))
        {

            $data = $this->getItem();
            $data->registed_mail = $this->getActiveLicense()->email;
	        $data->registed_token = $this->getActiveLicense()->token;
        }

        return $data;
    }
    /**
     * Method to check if it's OK to delete a message. Overrides JModelAdmin::canDelete
     */
    protected function canDelete($record)
    {
        if( !empty( $record->id ) )
        {
            return JFactory::getUser()->authorise( "core.delete", "com_hobosm.hobosm." . $record->id );
        }
        return false;
    }


    public function getLicense(){
	    // Initialize variables.
	    $db    = JFactory::getDbo();
	    $query = $db->getQuery(true);

	    // Create the base select statement.
	    $query->select('*')
		    ->from($db->quoteName('#__hobosm_license_active'));
	    $db->setQuery((string)$query);
	    $result = $db->loadObject();
	    return $result;
    }
	public function getAllLicense(){
		// Initialize variables.
		$db    = JFactory::getDbo();
		$query = $db->getQuery(true);

		// Create the base select statement.
		$query->select('*')
			->from($db->quoteName('#__hobosm_license'));
		$db->setQuery((string)$query);
		$result = $db->loadObjectList();
		return $result;
	}

}