<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  com_hobosm
 *
 * @copyright   Copyright (C) 2005 - 2018 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

/**
 * HelloWorld View
 *
 * @since  0.0.1
 */
class HobOsmViewHobOsm extends JViewLegacy
{
    protected $form;
    protected $item;
    protected $script;
    protected $canDo;

    /**
     * Display the Hello World view
     *
     * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
     *
     * @return  void
     */
    public function display($tpl = null)
    {
        // Get the Data
        $this->form = $this->get('Form');
        $this->item = $this->get('Item');
        $this->script = $this->get('Script');

        // What Access Permissions does this user have? What can (s)he do?
        $this->canDo = JHelperContent::getActions('com_hobosm', 'hobosm', $this->item->id);

        // Check for errors.
        if (count($errors = $this->get('Errors')))
        {
            throw new Exception(implode("\n", $errors), 500);
        }

        // Set the toolbar
        $this->addToolBar();

        // Display the template
        parent::display($tpl);

        // Set the document
        $this->setDocument();

        $this->addMap();
    }

    /**
     * Add the page title and toolbar.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function addToolBar()
    {
        $input = JFactory::getApplication()->input;

        // Hide Joomla Administrator Main menu
        $input->set('hidemainmenu', true);

        $isNew = ($this->item->id == 0);

        JToolBarHelper::title($isNew ? JText::_('COM_HOBOSM_MANAGER_HOBOSM_NEW')
            : JText::_('COM_HOBOSM_MANAGER_HOBOSM_EDIT'), 'hobosm');
        // Build the actions for new and existing records.
        if ($isNew)
        {
            // For new records, check the create permission.
            if ($this->canDo->get('core.create'))
            {
                JToolBarHelper::apply('hobosm.apply', 'JTOOLBAR_APPLY');
                JToolBarHelper::save('hobosm.save', 'JTOOLBAR_SAVE');
                JToolBarHelper::custom('hobosm.save2new', 'save-new.png', 'save-new_f2.png',
                    'JTOOLBAR_SAVE_AND_NEW', false);
            }
            JToolBarHelper::cancel('hobosm.cancel', 'JTOOLBAR_CANCEL');
        }
        else
        {
            if ($this->canDo->get('core.edit'))
            {
                // We can save the new record
                JToolBarHelper::apply('hobosm.apply', 'JTOOLBAR_APPLY');
                JToolBarHelper::save('hobosm.save', 'JTOOLBAR_SAVE');

                // We can save this record, but check the create permission to see
                // if we can return to make a new one.
                if ($this->canDo->get('core.create'))
                {
                    JToolBarHelper::custom('hobosm.save2new', 'save-new.png', 'save-new_f2.png',
                        'JTOOLBAR_SAVE_AND_NEW', false);
                }
            }
            if ($this->canDo->get('core.create'))
            {
                JToolBarHelper::custom('hobosm.save2copy', 'save-copy.png', 'save-copy_f2.png',
                    'JTOOLBAR_SAVE_AS_COPY', false);
            }
            JToolBarHelper::cancel('hobosm.cancel', 'JTOOLBAR_CLOSE');
        }
    }
    /**
     * Method to set up the document properties
     *
     * @return void
     */
    protected function setDocument()
    {
        $isNew = ($this->item->id == 0);
        $document = JFactory::getDocument();
        $document->setTitle($isNew ? JText::_('COM_HOBOSM_HOBOSM_CREATING')
            : JText::_('COM_HOBOSM_HOBOSM_EDITING'));
        $document->addScript(JURI::root() . $this->script);
        $document->addScript(JURI::root() . "/administrator/components/com_hobosm"
            . "/views/hobosm/submitbutton.js");
        JText::script('COM_HOBOSM_HOBOSM_ERROR_UNACCEPTABLE');
    }

    function addMap()
    {
        $document = JFactory::getDocument();

        // everything's dependent upon JQuery
        JHtml::_('jquery.framework');
        $document->addScript("https://cdn.polyfill.io/v2/polyfill.min.js?features=requestAnimationFrame,Element.prototype.classList,URL");
        // we need the Openlayers JS and CSS libraries
        $document->addScript("https://openlayers.org/en/v4.6.5/build/ol.js");
        $document->addStyleSheet("https://openlayers.org/en/v4.6.5/css/ol.css");
		$document->addScript('https://unpkg.com/ol-geocoder@3.3.0/dist/ol-geocoder.js');
		$document->addStyleSheet('https://unpkg.com/ol-geocoder@3.3.0/dist/ol-geocoder.min.css');
        // ... and our own JS and CSS
        $document->addScript(JURI::root() . "media/com_hobosm/js/openstreetmap_admin.js");
        $document->addStyleSheet(JURI::root() . "media/com_hobosm/css/openstreetmap.css");

        // get the data to pass to our JS code
        $params = $this->get("mapParams");
        $document->addScriptOptions('params', $params);
    }
}
