<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  com_helloworld
 *
 * @copyright   Copyright (C) 2005 - 2018 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

/**
 * HelloWorld Model
 *
 * @since  0.0.1
 */
class HobOsmModelHobOsm extends JModelItem
{
    /**
     * @var object item
     */
    protected $item;

    /**
     * Method to auto-populate the model state.
     *
     * This method should only be called once per instantiation and is designed
     * to be called on the first call to the getState() method unless the model
     * configuration flag to ignore the request is set.
     *
     * Note. Calling getState in this method will result in recursion.
     *
     * @return	void
     * @since	2.5
     */
    protected function populateState()
    {
        // Get the place id
        $jinput = JFactory::getApplication()->input;
        $id     = $jinput->get('id', 1, 'INT');
        $this->setState('place.id', $id);

        // Load the parameters.
        $this->setState('params', JFactory::getApplication()->getParams());
        parent::populateState();
    }
    /**
     * Method to get a table object, load it if necessary.
     *
     * @param   string  $type    The table name. Optional.
     * @param   string  $prefix  The class prefix. Optional.
     * @param   array   $config  Configuration array for model. Optional.
     *
     * @return  JTable  A JTable object
     *
     * @since   1.6
     */
    public function getTable($type = 'HobOsm', $prefix = 'HobOsmTable', $config = array())
    {
        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Get the place
     * @return object The place to be displayed to the user
     */
    public function getItem()
    {
        if (!isset($this->item))
        {
            $id    = $this->getState('place.id');
            $db    = JFactory::getDbo();
            $query = $db->getQuery(true);
            $query->select('h.name as name,h.greeting, h.params, h.image as image, c.title as category, h.latitude as latitude, h.longitude as longitude, h.zoom as zoom, h.scale as scale, h.width as width, h.position_horizontal as position_horizontal, h.position_vertical as position_vertical')
                ->from('#__hobosm as h')
                ->leftJoin('#__categories as c ON h.catid=c.id')
                ->where('h.id='.$id);
            $db->setQuery((string)$query);

            if ($this->item = $db->loadObject())
            {
                // Load the JSON string
                $params = new JRegistry;
                $params->loadString($this->item->params, 'JSON');
                $this->item->params = $params;

                // Merge global params with item params
                $params = clone $this->getState('params');
                $params->merge($this->item->params);
                $this->item->params = $params;

                // Convert the JSON-encoded image info into an array
                $image = new JRegistry;
                $image->loadString($this->item->image, 'JSON');
                $this->item->imageDetails = $image;
            }
        }
        return $this->item;
    }

    public function getMapParams()
    {
        if ($this->item)
        {
            $this->mapParams = array(
                'latitude' => $this->item->latitude,
                'longitude' => $this->item->longitude,
                'zoom' => $this->item->zoom,
                'greeting' => $this->item->greeting,
                'horizontal'=>$this->item->position_horizontal,
                'vertical'=>$this->item->position_vertical,
                'icon_scale'=>$this->item->scale,
                'image'=>$this->item->image,
                'width'=>$this->item->width,
                'name'=>$this->item->name
            );
            return $this->mapParams;
        }
        else
        {
            throw new Exception('No helloworld details available for map', 500);
        }
    }
}